<?php

namespace Ems\portalGestor\Controller;

use Ems\portalGestor\Service\MonitoramentoService;
use Zeedhi\Framework\Controller\CrudNext;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\Manager\Doctrine\NameProvider;
use Zeedhi\Framework\DTO\Response\Error;

class MonitoramentoController
{
    protected $monitoramentoService;

    public function __construct(MonitoramentoService $monitoramentoService) {
        $this->monitoramentoService = $monitoramentoService;
    }

    public function getMonitoramentoEquipeBancoHoras(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg         = (int) $row['NRORG'];
            $nrEstrutura   = (int) $row['NRESTRUTURAM'];
            $nrPeriodo     = (int) $row['NRPERIODOAPURACAO'];

            $saldoBancoDeHoras = $this->monitoramentoService->
                getMonitoramentoEquipeBancoHoras($nrOrg, $nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('data', $saldoBancoDeHoras));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeAtrasos(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg       = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $atrasos = $this->monitoramentoService->
                getMonitoramentoEquipeAtrasos($nrOrg, $nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('data', $atrasos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeFaltas(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg       = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $faltas = $this->monitoramentoService->
                getMonitoramentoEquipeFaltas($nrOrg, $nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('data', $faltas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeHorasExtras(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg       = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $horasExtras = $this->monitoramentoService->
                getMonitoramentoEquipeHorasExtras($nrOrg, $nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('data', $horasExtras));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeAtestados(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg       = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $atestados = $this->monitoramentoService->
                getMonitoramentoEquipeAtestados($nrOrg, $nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('data', $atestados));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeFerias(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg       = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $ferias = $this->monitoramentoService->
                getMonitoramentoEquipeFerias($nrOrg, $nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('data', $ferias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeContrato(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];

            $contratos = $this->monitoramentoService->
                getMonitoramentoEquipeContrato($nrOrg, $nrEstrutura);

            $response->addDataSet(new DataSet('data', $contratos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeLicenca(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];

            $licencas = $this->monitoramentoService->
                getMonitoramentoEquipeLicenca($nrOrg, $nrEstrutura);

            $response->addDataSet(new DataSet('data', $licencas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeAfastamentos(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $afastamentos = $this->monitoramentoService->
                getMonitoramentoEquipeAfastamentos($row);

            $response->addDataSet(new DataSet('data', $afastamentos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeUltimasFerias(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg       = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $ultFerias = $this->monitoramentoService->
                getMonitoramentoEquipeUltimasFerias($nrOrg, $nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('data', $ultFerias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
