<?php

namespace Ems\portalGestor\Service;

use Doctrine\ORM\EntityManager;
use Ems\portalGestor\Util\DateUtil;
use Ems\portalGestor\Service\EstruturaService;
use Ems\portalGestor\Repository\OperadorRepository;
use Ems\portalGestor\Repository\MonitoramentoRepository;
use Ems\portalGestor\Service\DemonstrativoService;
use Ems\portalGestor\Util\Util;
use Ems\portalGestor\Util\ArrayUtil;
use Ems\portalGestor\Util\HcmServices;

class MonitoramentoService
{
    /** @var HcmServices $hcmServices */
    public $hcmSevices;

    /** @var OperadorRepository $operadorRepository */
    protected $operadorRepository;

    public function __construct(
        OperadorRepository $operadorRepository,
        MonitoramentoRepository $monitoramentoRepository,
        DemonstrativoService $demonstrativoService,
        EstruturaService $estruturaService,
        HcmServices $hcmServices
    ) {
        $this->operadorRepository      = $operadorRepository;
        $this->monitoramentoRepository = $monitoramentoRepository;
        $this->demonstrativoService    = $demonstrativoService;
        $this->estruturaService        = $estruturaService;
        $this->hcmServices              = $hcmServices;
    }

    public function getMonitoramentoEquipeBancoHoras(
        int $nrOrg,
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {

        $hcmServicesRoute = 'getMonitoramentoEquipeBancoHoras';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $banco = $response['dataset'][$hcmServicesRoute];

        return $banco;
    }

    public function getMonitoramentoEquipeAtrasos(
        int $nrOrg,
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {

        $hcmServicesRoute = 'getMonitoramentoEquipeAtrasos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $atrasos = $response['dataset'][$hcmServicesRoute];

        return $atrasos;
    }

    public function getMonitoramentoEquipeFaltas(
        int $nrOrg,
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {

        $hcmServicesRoute = 'getMonitoramentoEquipeFaltas';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $faltas = $response['dataset'][$hcmServicesRoute];

        return $faltas;
    }

    public function getMonitoramentoEquipeHorasExtras(
        int $nrOrg,
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {

        $hcmServicesRoute = 'getMonitoramentoEquipeHorasExtras';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $horas = $response['dataset'][$hcmServicesRoute];

        return $horas;
    }

    public function getMonitoramentoEquipeAtestados(
        int $nrOrg,
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {

        $hcmServicesRoute = 'getMonitoramentoEquipeAtestados';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $atestados = $response['dataset'][$hcmServicesRoute];

        return $atestados;
    }

    public function getMonitoramentoEquipeFerias(
        int $nrOrg,
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {

        $hcmServicesRoute = 'getMonitoramentoEquipeFerias';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $ferias = $response['dataset'][$hcmServicesRoute];

        return $ferias;
    }

    public function getMonitoramentoEquipeContrato(
        int $nrOrg,
        int $nrEstrutura
    ): array {

        $hcmServicesRoute = 'getMonitoramentoEquipeContrato';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $contratos = $response['dataset'][$hcmServicesRoute];

        return $contratos;
    }

    public function getMonitoramentoEquipeLicenca(
        int $nrOrg,
        int $nrEstrutura
    ): array {

        $hcmServicesRoute = 'getMonitoramentoEquipeLicenca';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $licencas = $response['dataset'][$hcmServicesRoute];

        return $licencas;
    }

    public function getMonitoramentoEquipeAfastamentos(
        array $row
    ): array {

        $hcmServicesRoute = 'getMonitoramentoEquipeAfastamentos';
        $nrOrg = (int) $row['NRORG'];
        $nrEstrutura = (int) $row['NRESTRUTURAM'];

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $afastamentos = $response['dataset'][$hcmServicesRoute];

        return $afastamentos;
    }

    public function getMonitoramentoEquipeUltimasFerias(
        int $nrOrg,
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {

        $hcmServicesRoute = 'getMonitoramentoEquipeUltimasFerias';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $ultFerias = $response['dataset'][$hcmServicesRoute];

        return $ultFerias;
    }
}
