<?php
namespace Ems\portalGestor\Service;

use Ems\portalGestor\Repository\PeriodoRepository;
use Ems\portalGestor\Repository\VinculoRepository;

class PeriodoService {

    /** @var PeriodoRepository */
    protected $periodoRepository;

    /** @var VinculoRepository */
    protected $vinculoRepository;

    public function __construct(
        PeriodoRepository $periodoRepository,
        VinculoRepository $vinculoRepository
    ) {
        $this->periodoRepository = $periodoRepository;
        $this->vinculoRepository = $vinculoRepository;
    }

    public function getNrPeriodoEquivalente(
        int $nrOrg,
        int $nrVinculo,
        string $nrPeriodo
    ): int {
        $periodo = $this->periodoRepository->get($nrOrg, $nrPeriodo);
        $dtInicial = (string) $periodo['DTINICIALAPURACAO'];

        $vinculo = $this->vinculoRepository->get($nrOrg, $nrVinculo);
        $nrTipoVinculo = (int) $vinculo['NRTIPOVINCULOM'];

        $params = [
            'P_NRORG' => $nrOrg,
            'P_DTINICIAL' => $dtInicial,
            'P_NRTIPOVINCULO' => $nrTipoVinculo,
        ];

        $periodoEquivalente = $this->periodoRepository->getPeriodoByDtIniNrTipoVinculo(
            $params
        );

        if ($periodoEquivalente === false) {
            $err = "Não foi encontrado um período equivalente para o vínculo do tipo $nrTipoVinculo";
            throw new \Exception($err);
        }

        $nrPeriodoEquivalente = (int) $periodoEquivalente['NRPERIODOAPURACAO'];

        return $nrPeriodoEquivalente;
    }
}
